pub struct Client<'a, S> { /* private fields */ }
A type which emulates a connection to a peer.

Implementations

Applies an HTTP request to this client and get its response.

Returns the reference to the underlying Tokio runtime.