[−][src]Struct tsukuyomi_server::Server
An HTTP server.
Methods
impl<S> Server<S>[src]
impl<S> Server<S>pub fn new(make_service: S) -> Self[src]
pub fn new(make_service: S) -> SelfCreate a new Server with the specified NewService and default configuration.
impl<S, L, A, R> Server<S, L, A, R>[src]
impl<S, L, A, R> Server<S, L, A, R>pub fn bind<L2>(self, listener: L2) -> Server<S, L2, A, R> where
L2: Listener, [src]
pub fn bind<L2>(self, listener: L2) -> Server<S, L2, A, R> where
L2: Listener, Sets the transport used by the server.
By default, a TCP transport with the listener address "127.0.0.1:4000" is set.
pub fn acceptor<A2>(self, acceptor: A2) -> Server<S, L, A2, R> where
L: Listener,
A2: Acceptor<L::Conn>, [src]
pub fn acceptor<A2>(self, acceptor: A2) -> Server<S, L, A2, R> where
L: Listener,
A2: Acceptor<L::Conn>, Sets the instance of Acceptor to the server.
By default, the raw acceptor is set, which returns the incoming I/Os directly.
pub fn protocol(self, protocol: Http) -> Self[src]
pub fn protocol(self, protocol: Http) -> SelfSets the HTTP-level configuration to this server.
Note that the executor will be overwritten by the launcher.
pub fn runtime<R2>(self, runtime: R2) -> Server<S, L, A, R2>[src]
pub fn runtime<R2>(self, runtime: R2) -> Server<S, L, A, R2>Sets the instance of runtime to the specified runtime.
pub fn current_thread(self) -> Server<S, L, A, Runtime>[src]
pub fn current_thread(self) -> Server<S, L, A, Runtime>Switches the runtime to be used to current_thread::Runtime.
impl<S, T, A, Bd> Server<S, T, A, Runtime> where
S: MakeServiceRef<A::Conn, Request<Body>, Response = Response<Bd>> + Send + Sync + 'static,
S::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
S::MakeError: Into<Box<dyn Error + Send + Sync + 'static>>,
S::Future: Send + 'static,
S::Service: Send + 'static,
<S::Service as Service<Request<Body>>>::Future: Send + 'static,
Bd: Payload,
T: Listener,
T::Incoming: Send + 'static,
A: Acceptor<T::Conn> + Send + 'static,
A::Conn: Send + 'static,
A::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
A::Accept: Send + 'static, [src]
impl<S, T, A, Bd> Server<S, T, A, Runtime> where
S: MakeServiceRef<A::Conn, Request<Body>, Response = Response<Bd>> + Send + Sync + 'static,
S::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
S::MakeError: Into<Box<dyn Error + Send + Sync + 'static>>,
S::Future: Send + 'static,
S::Service: Send + 'static,
<S::Service as Service<Request<Body>>>::Future: Send + 'static,
Bd: Payload,
T: Listener,
T::Incoming: Send + 'static,
A: Acceptor<T::Conn> + Send + 'static,
A::Conn: Send + 'static,
A::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
A::Accept: Send + 'static, impl<S, T, A, Bd> Server<S, T, A, Runtime> where
S: MakeServiceRef<A::Conn, Request<Body>, Response = Response<Bd>> + 'static,
S::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
S::MakeError: Into<Box<dyn Error + Send + Sync + 'static>>,
S::Future: 'static,
S::Service: 'static,
<S::Service as Service<Request<Body>>>::Future: 'static,
Bd: Payload,
T: Listener,
T::Incoming: 'static,
A: Acceptor<T::Conn> + 'static,
A::Conn: Send + 'static,
A::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
A::Accept: 'static, [src]
impl<S, T, A, Bd> Server<S, T, A, Runtime> where
S: MakeServiceRef<A::Conn, Request<Body>, Response = Response<Bd>> + 'static,
S::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
S::MakeError: Into<Box<dyn Error + Send + Sync + 'static>>,
S::Future: 'static,
S::Service: 'static,
<S::Service as Service<Request<Body>>>::Future: 'static,
Bd: Payload,
T: Listener,
T::Incoming: 'static,
A: Acceptor<T::Conn> + 'static,
A::Conn: Send + 'static,
A::Error: Into<Box<dyn Error + Send + Sync + 'static>>,
A::Accept: 'static, Trait Implementations