pub struct LocalServer<S> { /* private fields */ }
A local server which emulates an HTTP service without using the low-level transport.

The value of this struct conttains an instance of NewHttpService and a Tokio runtime.

Implementations

Creates a new instance of LocalServer from a NewHttpService.

This function will return an error if the construction of the runtime is failed.

Create a Client associated with this server.